==> haskell-x11-1.6.1.2-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x11/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.6.1.2
id: X11-1.6.1.2-4670912ab0053621e433826e2cb4ea46
key: X11_Bv0OaUTBEUKFXXAIRnU0RN
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/haskell-pkg-janitors/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.Types Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Font Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Extras
    Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.XScreenSaver
    Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault
hidden-modules: Graphics.X11.Xlib.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/X11-1.6.1.2
hs-libraries: HSX11-1.6.1.2-Bv0OaUTBEUKFXXAIRnU0RN
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-1.6.1.2-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x11/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11
version: 1.6.1.2
id: X11-1.6.1.2-e77778265c7135c63ab82aead415c843
key: X11_1GsQtr5XqYe4jm5CJvyQR7
license: BSD3
copyright: Alastair Reid, 1999-2003, libraries@haskell.org 2003-2007, Don Stewart 2007-2009, Spencer Janssen 2007-2009, Daniel Wagner 2009-2011.
maintainer: Daniel Wagner <daniel@wagner-home.com>
homepage: https://github.com/haskell-pkg-janitors/X11
synopsis: A binding to the X11 graphics library
description:
    A Haskell binding to the X11 graphics library.
    The binding is a direct translation of the C binding; for
    documentation of these calls, refer to "The Xlib Programming
    Manual", available online at <http://tronche.com/gui/x/xlib/>.
category: Graphics
exposed: True
exposed-modules:
    Graphics.X11 Graphics.X11.Types Graphics.X11.Xlib
    Graphics.X11.Xlib.Atom Graphics.X11.Xlib.Color
    Graphics.X11.Xlib.Context Graphics.X11.Xlib.Cursor
    Graphics.X11.Xlib.Display Graphics.X11.Xlib.Event
    Graphics.X11.Xlib.Font Graphics.X11.Xlib.Misc
    Graphics.X11.Xlib.Region Graphics.X11.Xlib.Screen
    Graphics.X11.Xlib.Types Graphics.X11.Xlib.Window
    Graphics.X11.Xlib.Image Graphics.X11.Xlib.Extras
    Graphics.X11.Xinerama Graphics.X11.Xrandr Graphics.X11.XScreenSaver
    Graphics.X11.ExtraTypes Graphics.X11.ExtraTypes.AP
    Graphics.X11.ExtraTypes.DEC Graphics.X11.ExtraTypes.HP
    Graphics.X11.ExtraTypes.Sun Graphics.X11.ExtraTypes.XF86
    Graphics.X11.ExtraTypes.XorgDefault
hidden-modules: Graphics.X11.Xlib.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/X11-1.6.1.2
hs-libraries: HSX11-1.6.1.2-1GsQtr5XqYe4jm5CJvyQR7
extra-libraries:
    Xinerama Xext X11 Xrandr Xext
include-dirs: /usr/lib/ghc-7.10.3/site-local/X11-1.6.1.2/include
includes:
    HsXlib.h HsAllKeysyms.h
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-x11/html/X11.haddock
haddock-html: /usr/share/doc/haskell-x11/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
